Access to the finest wines at attractive prices | Lot18
Description: Lot18 provides access to high-quality, hard-to-find wines from around the globe – all at the best possible prices.
Keywords: wine, wine shop, wine clubs, wine club, top rated, top selling, wine basics, top, rated, champagne, california, region, varietal, cabernet, merlot, pinot

[ { "label": "Home", "url": "/" }, { "label": "Collection", "url": "/boutiques" } ]
[ { "label": "Account Basics", "url": "/account" }, { "label": "Order History", "url": "/account/orders" }, { "label": "Address Management", "url": "/account/addresses" }, { "label": "Credit Card Management", "url": "/account/credit_cards" }, { "label": "My Lot18 Credit", "url": "/account/credit" }, { "label": "Preferences", "url": "/account/preferences" }, { "label": "Logout", "url": "/logout" } ]
Products Account NJ
Lot18 Home
Log in Register

## What's hot today

$110 off
Wine Rack Refill: Holiday Dinner Party Edition More than enough wine to make it through all the holiday meals you're hosting
$219.98 $330.00 MSRP
OFFER DETAILS
$45 off
2011 Penfolds Bin 389 Australia Cabernet-Shiraz Magnum A big, classic red by one of the world's greatest wineries at an affordable price
$129.99 $175.00 MSRP
OFFER DETAILS
$57 off
New World Reds Half Case Big, bold reds that thumb their noses at Europe
$124.99 $182.00 MSRP
OFFER DETAILS
Featured
2009 Argiano Brunello di Montalcino The sleek, modern-style Brunello all the critics love
$59.99
OFFER DETAILS
Enter the Collection
Browse Featured Offers
Loading...

### About Lot18

### Customer Support

### Connect

1-855-MYLOT18
1-855-MYLOT18
2 Clark Place, Mahopac, NY 10541
ALL ALCOHOLIC BEVERAGES PURCHASED FROM LOT18 ARE SOLD IN THE STATE OF CALIFORNIA AND TITLE PASSES TO THE BUYER IN CALIFORNIA. Lot18 makes no representation to the legal rights of anyone to ship or import alcoholic beverages into any state outside of California. The buyer is solely responsible for the shipment of alcoholic beverage products. By placing an order with Lot18, buyer authorizes Lot18 to act on buyer’s behalf to engage a common carrier to deliver buyer’s order.